#
# spec file for package gettext-java
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gettext-java
Version:        0.21.1
Release:        150600.3.3.2
Summary:        Java Support for Native Language Support (NLS)
License:        LGPL-2.1-or-later
Group:          Development/Tools/Other
URL:            https://www.gnu.org/software/gettext/
Source0:        https://ftp.gnu.org/gnu/gettext/gettext-%{version}.tar.xz
Source1:        https://ftp.gnu.org/gnu/gettext/gettext-%{version}.tar.xz.sig
Source2:        suse-start-po-mode.el
Source3:        gettext-linkdupes.sh
Source4:        gettext-rpmlintrc
Source5:        gettext-runtime.keyring
Patch0:         gettext-0.12.1-sigfpe.patch
Patch1:         gettext-0.19.3-fix-bashisms.patch
Patch2:         gettext-0.12.1-gettextize.patch
Patch3:         use-acinit-for-libtextstyle.patch
Patch4:         gettext-po-mode.diff
Patch5:         gettext-initialize_vars.patch
# PATCH-FIX-OPENSUSE gettext-dont-test-gnulib.patch -- coolo@suse.de
Patch6:         gettext-dont-test-gnulib.patch
Patch7:         gettext-0.21-jdk17.patch
# PATCH-FIX-UPSTREAM boo#941629 -- pth@suse.com
Patch11:        boo941629-unnessary-rpath-on-standard-path.patch
# PATCH-FIX-SUSE Bug boo#1106843
Patch13:        reproducible.patch
# PATCH-FEATURE bsc#1165138
Patch14:        0001-msgcat-Add-feature-to-use-the-newest-po-file.patch
Patch15:        0002-msgcat-Merge-headers-when-use-first.patch
# PATCH-FEATURE-FIX-SUSE boo#1227316 -- sbrabec@suse.com
Patch16:        0003-Fix-malformed-header-processing.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  java-devel >= 1.8
BuildRequires:  libtextstyle-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  perl-libintl-perl
BuildRequires:  tcl

%if 0%{?fedora_version} || 0%{?centos_version} <= 600 || 0%{?scilin_version} <= 600 || 0%{?rhel_version} <= 600
%global debug_package %{nil}
%endif

%description
This package includes the tools needed to support message catalogs in
Java applications. It also includes example code for java, java+awt and
java+swing.

%prep
%setup -q -n gettext-%{version}
%patch0
%patch1 -p1
%patch2
%patch3 -p1
%patch4
%patch5
%patch6 -p1
%patch7 -p1
%patch11 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1

%build
# expect a couple "You should update your `aclocal.m4' by running aclocal."
autoreconf -fiv
export CFLAGS="%{optflags} -pipe -W -Wall -Dgcc_is_lint -lm"
export CXXFLAGS="%{optflags} -pipe -W -Wall -Dgcc_is_lint"
%configure --enable-shared  --enable-java
make GMSGFMT=../src/msgfmt %{?_smp_mflags} V=1

%install
export LC_CTYPE=ISO-8859-15
make -C gettext-tools/gnulib-lib install DESTDIR=%{buildroot}
make -C gettext-tools/src         install DESTDIR=%{buildroot}
make -C gettext-runtime/intl-java install DESTDIR=$PWD docdir=/docs
make -C gettext-tools/examples    install DESTDIR=$PWD docdir=/allexamples
mkdir -p docs/examples
mv allexamples/examples/*java* docs/examples
cd docs/examples
fdupes -r *|while read dupe; do
	if [ -z "$dupe" ]; then
		startlink=
	elif [ -z "$startlink" ]; then
		startlink="$dupe"
	else
		ln -f "$startlink" "$dupe"
	fi
done
cd ..
find -type f -size 0 -delete
mkdir -p %{buildroot}%{_libdir}/gettext
mv %{buildroot}/%{_datadir}/gettext/gettext.jar %{buildroot}%{_libdir}/gettext/
# Create scripts that will launch the tools
for i in gnu.gettext.DumpResource gnu.gettext.GetURL; do
cat <<EOF > %{buildroot}%{_libdir}/gettext/$i
#!/bin/sh
exec java -cp %{_libdir}/gettext/gettext.jar $i \${1+\$@}
EOF
chmod +x %{buildroot}%{_libdir}/gettext/$i
done
rm -rf   %{buildroot}/%{_datadir}/*
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}
cp -av * %{buildroot}/%{_defaultdocdir}/%{name}
cd ../allexamples/examples
rm -rf *csharp*
fdupes -r * | while read dupe; do
	if [ -z "$dupe" ]; then
		startlink=
	elif [ -z "$startlink" ]; then
		startlink="$dupe"
	else
		echo "ln -f '$startlink' '$dupe'" >>../../gettext-linkdupes.sh
	fi
done
diff %{SOURCE3} . || {
	cat <<END
	######################################################
	######################################################
	## Updated gettext-linkdupes.sh in $PWD ##
	######################################################
	######################################################
END
}
ls -l %{buildroot}/%{_datadir}
# exclude files packaged via other spec files
rm -rf %{buildroot}/%{_bindir}
rm -f %{buildroot}/%{_libdir}/lib*
rm -f %{buildroot}/%{_libdir}/gettext/hostname
rm -f %{buildroot}/%{_libdir}/gettext/project-id
rm -f %{buildroot}/%{_libdir}/gettext/urlget
rm -f %{buildroot}/%{_libdir}/gettext/user-email
rm -f %{buildroot}/%{_libdir}/gettext/cldr-plurals

%files
%{_defaultdocdir}/%{name}
%{_libdir}/gettext/gettext.jar
%{_libdir}/gettext/gnu.gettext.DumpResource
%{_libdir}/gettext/gnu.gettext.GetURL

%changelog
* Wed Feb 26 2025 sbrabec@suse.com
- Fix crash while handling po files with malformed header and
  process them properly
  (0003-Fix-malformed-header-processing.patch, boo#1227316).
* Thu May  4 2023 fcrozat@suse.com
- Add _multibuild to define additional spec files as additional
  flavors.
  Eliminates the need for source package links in OBS.
* Fri Apr  8 2022 fstrba@suse.com
- Added patch:
  * gettext-0.21-jdk17.patch
    + Build with java source and target levels 1.8
    + Allows building with JDK17
    + Fixes build in Factory
* Mon Nov 29 2021 mgorse@suse.com
- Remove libcroco from BuildRequires: it is now bundled internally.
* Fri Jan 22 2021 dmueller@suse.com
- use https for urls
- apply all the patches from gettext-runtime
* Tue Jul 28 2020 christian.voegl@suse.com
- Updated to version 0.21
  - Java:
    o xgettext now recognizes format strings in the Formatter syntax.  They
    are marked as 'java-printf-format' in POT and PO files.
    o xgettext now recognizes text blocks as string literals.
  - Improvements for translators:
    o  When msgfmt writes a MO file, it now does so in such a way that processes
    that are currently using an older copy of the MO file will not crash.
* Tue Jun 11 2019 christian.voegl@suse.com
- Updated to version 0.20.1
  + msgfmt now eliminates the POT-Creation-Date header field from .mo files.
  + update-po target in Makefile.in.in now uses msgmerge --previous.
  + msgmerge now has an option --for-msgfmt, that produces a PO file meant
    for use by msgfmt only.  This option saves processing time, in particular
    by omitting fuzzy matching that is not useful in this situation.
  + The .pot file in a 'po' directory is now erased by "make maintainer-clean".
  + It is now possible to override xgettext options from the po/Makefile.in.in
    through options in XGETTEXT_OPTIONS (declared in po/Makevars).
  + The --intl option of the gettextize program (deprecated since 2010) is
    no longer available. Instead of including the intl sources in your package,
    we suggest making the libintl library an optional prerequisite of your
    package. This will simplify the build system of your package.
  + Accordingly, the Autoconf macro AM_GNU_GETTEXT_INTL_SUBDIR is gone as well.
  + Java:
  * xgettext now supports UTF-8 encoded .properties files (a new feature
    of Java 9).
  * The build system and tools now support Java 9, 10, and 11. On the
    other hand, support for old versions of Java (Java 5 and older,
    GCJ 4.2.x and older) has been dropped.
- Rebased gettext-po-mode.diff
- Removed gettext-needlessly_init_vars.patch (now in upstream)
- Removed gettext-0.19.8.1-jdk9.patch (now in upstream)
* Mon May 14 2018 antoine.belvire@opensuse.org
- Remove prereq on info: No info page installed.
* Wed Oct 18 2017 jayvdb@gmail.com
- Replace deprecated PreReq: with Requires(post): and Requires(preun):
- Disable debug packages on RHEL and derived distributions
* Tue Oct  3 2017 fstrba@suse.com
- Added patch:
  * gettext-0.19.8.1-jdk9.patch
    + specify java soure and target level 6 to be able to build
    with jdk9
- Do not depend on gcc-java and do not build native binaries of the
  gnu.gettext.GetURL and gnu.gettext.DumpResource tools, since
  gcc-java is bound to disappear
- Build the gettext.jar using any java-devel provider and make the
  gnu.gettext.GetURL and gnu.gettext.DumpResource tools scripts
  running classes from this gettext.jar
- Clean the spec file a bit
* Sun Jun 19 2016 astieger@suse.com
- GNU gettext 0.19.8.1:
  * Fix unintentional soname bump
* Sat Jun 11 2016 astieger@suse.com
- GNU gettext 0.19.8:
  * msgfmt now produces little-endian .mo files by default.
  * xml: xgettext and msgfmt now look for .its files in directories
    supplied through the GETTEXTDATADIRS or XDG_DATA_DIRS
    environment variable.
  * JavaScript: xgettext and msgfmt now recognize numbered
    arguments in format strings.
* Mon Apr  4 2016 astieger@suse.com
- GNU gettext 0.19.7:
  * can now load custom string extraction rules in XML
    Internationalization Tag Set (ITS) standard
  * the existing XML-based language scanners (Glade, GSettings, and
    AppData) rewritten using ITS
  * Add msgfmt --xml option to merge translations back to the
    original XML document.
* Fri Sep 11 2015 astieger@suse.com
- GNU gettext 0.19.6:
  * Support AppData file format
* Thu Jul 16 2015 astieger@suse.com
- GNU gettext 0.19.5.1:
  * fix build on old platforms where stpcpy and stpncpy is missing
* Fri Jul 10 2015 astieger@suse.com
- GNU gettext 0.19.5:
  * drop gettext-check-allocated-size-for-static-segment.patch,
    is upstream
* Tue Mar 10 2015 mlin@suse.com
- Add gettext-check-allocated-size-for-static-segment.patch from upstream
  * Check if the embedded segment size is valid, before adding it to
    the string length. Please see
    http://lists.gnu.org/archive/html/bug-gettext/2015-03/msg00005.html
* Tue Jan 27 2015 andreas.stieger@gmx.de
- GNU gettext 0.19.4:
  * The --keyword option of xgettext now accepts same argument
    number for both singular and plural forms.
  * Programming languages support:
  - C#: xgettext now properly handles Unicode characters encoded
    with surrogate pairs.
  - C/C++: xgettext now recognizes ISO/IEC 9899:2011 string
    literals prefixed by R, u8, u8R, u, uR, U, UR, L, or LR.
  - Shell: xgettext now properly recognizes Bash ANSI-C quoting
    ($'...').
  * Bug fixes:
  - Fix integer overflow when reading certain MO files with
    msgunfmt.
  - Avoid invalid memory access in various cases.  In particular,
    when the same argument number is specified for singular/
    plural arguments, and when checking Lisp and Scheme format
    strings.
* Fri Oct 17 2014 andreas.stieger@gmx.de
- GNU gettext 0.19.3:
  * Fix xgettext mishandling of octal character escapes in C.
  * Fix autopoint infinite recursion with certain configure.ac.
  * The po/Makevars file has a new field MSGINIT_OPTIONS, that can
    be used to adjust msginit's operation.  This is particularly
    useful for controlling line wrapping behavior together with
    MSGMERGE_OPTIONS and XGETTEXT_OPTIONS.
* Tue Jul 15 2014 pth@suse.de
- Update to 0.19.2:
  * Fix xgettext crash in parsing empty string literals in C and Vala.
  * Autoconf macro trace in autopoint now works again with Autoconf 2.68
    or earlier.  It was a regression in 0.19.
* Tue Jun 10 2014 andreas.stieger@gmx.de
- GNU gettext 0.19.1:
  * Desktop Entry: msgfmt now always reads the po/LINGUAS file
  * Vala:  Bug fix in xgettext handling of "//" in string literals
  * po/Makevars.template now contains the newly added variables
  * msgfmt now treats errors in the PO file header as non-fatal
    In future Gettext versions, msgfmt will treat header errors as
    fatal and terminate the command execution.
- switch to xz tarball
* Tue Jun  3 2014 andreas.stieger@gmx.de
- GNU gettext 0.19:
  - Programming languages support:
  * Desktop Entry:
    xgettext and msgfmt now support .desktop files, used by
    desktop applications, as input and output.
  * GSettings:
    xgettext now supports GSettings schema file format used by
    GNOME applications.
  * JavaScript:
    xgettext now recognizes E4X (ECMA-357) constructs.
  * PHP:
    Single and double quotes around heredoc markers are now
    recognized.
  * Python:
    The acceptable format specifiers in the braced-syntax format
    strings is now limited to the Standard Format Specifiers, to
    reasonably avoid false-positives.
  * Scheme:
    The gettext shorthand form _"abc", used by GIMP script-fu, is
    now recognized by xgettext.
  * C and Vala:
    xgettext now recognizes C99-style Unicode character escapes.
  - The --add-location option of msgattrib, msgcat, msgcomm,
    msgconv, msgen, msgfilter, msggrep, msgmerge, msguniq, and
    xgettext commands now takes an optional argument 'never',
    'full', or 'file', to control the format of "#: ..." comments.
  - msgfmt now has --source option to keep generated .java file
    when running in Java mode.
  - msgattrib now has --empty option that sets msgstr to empty when
    clearing fuzzy flag.
  * msgexec and msgfilter pass the plural information to subprocess
    through the environment variable MSG{EXEC,FILTER}_MSGID_PLURAL
    and MSG{EXEC,FILTER}_PLURAL_FORM.
  * New built-in filters 'quot' and 'boldquot' have been added to
    msgfilter.  These filters convert Latin quotation marks ('...',
    "...") into Unicode quotation marks (for example, U+2018) if
    possible, similar to the sed commands used in po/Rules-quot and
    po/Rules-boldquot.
  * The po/Makevars file has a couple of new options
    PO_DEPENDS_ON_POT and DIST_DEPENDS_ON_UPDATE_PO, that can be
    used to adjust the behavior of updating PO files on demand.
  * xgettext now strips prefixed string before the comment tag.
    This is useful to support C-style comment like this:
    /*
  * TRANSLATORS: first line
  * second line
  * /
  * In this example, the extracted comment does not contain "* " at
    the beginning of each line.
  * libgettextpo library:
  - Memory leak fixes in the PO file parser.
  * Documentation:
  - A complete example showing the use of GNU gettext in a
    GNOME 3 application has been added
* Sun Jan 12 2014 andreas.stieger@gmx.de
- GNU gettext 0.18.3.2:
  * Add missing extern-inline.m4 into archive.
- verify source signature
* Mon Aug 12 2013 christoph.miebach@web.de
- Version 0.18.3 - July 2013
  * Runtime behaviour:
    On Mac OS X systems, the setlocale() function now properly
    invalidates loaded message catalogs when a locale has been set.
  * Programming languages support:
  - C++:
    The gnu::autosprintf class now provides an assignment
    operator.
  - Glade:
    xgettext now supports GtkBuider file format used by Glade 3.
    xgettext now also extracts contexts (msgctxt) from Glade 2
    and GtkBuider files.
  - JavaScript:
    xgettext now partially supports JavaScript.  Since the
    current JavaScript specification (ECMA-262) does not define
    the standard set of formatting methods nor translation
    functions, the implementation supports only a limited
    set of formatting methods and translation functions commonly
    used in Gjs and other popular JavaScript implemenations and
    libraries.
  - Lua:
    xgettext now supports Lua, using Ľubomír Remák's lua-gettext.
  - Python:
    xgettext and msgfmt's format string checking now recognize
    Python format string in braced syntax (PEP 3101).  xgettext
    now also supports explicit string concatenation with '+' and
    handles platform dependent line terminators (LF/CR/CRLF)
    transparently.
  - Tcl:
    Bug fix in xgettext Unicode escape handling.
  - Vala:
    xgettext now supports Vala.
  * msgattrib now has --previous option to keep previous msgid when
    making messages fuzzy, similar to msgmerge --previous.
  * msgfmt now checks PO file headers more strictly with less
    false-positives.
  * 'gettextize' now checks macro directories specified with
    AC_CONFIG_MACRO_DIRS in configure.ac.
  * Portability:
  - msginit now does not require GNU sed.
  - The Makefile rule for generating en@quot and en@boldquot now
    uses @SED@ variable instead of hard-coded 'sed' command to
    allow users to supply GNU sed.
  * Future backward-incompatibilities:
  - In future Gettext versions, the files installed by
    'gettextize' will require Automake 1.10 or later.  This will
    improve the compatibility of user projects with newer
    Automake versions.
- Remove upstreamed patches:
  gettext-configure.patch
* Sat Jun 15 2013 schwab@linux-m68k.org
- Add glib2-devel libcroco-devel libxml2-devel to build requires to avoid
  using the included copies.
- gettext-configure.patch: Fix syntax in libxml check to avoid spurious
  failure
* Sat Jun  8 2013 christoph.miebach@web.de
- Update to version 0.18.2.1: Version 0.18.2 - December 2012
  + xgettext now understands the block comment syntax of Guile 2.0.
  + libgettextpo library:
  * The initial msgstr of a new message is now "", not NULL.
  * Bug fixes in the functions po_message_is_range,
    po_file_check_all, po_message_check_all.
  + Installation options:
    The configure options --with-xz and --with-bzip2 can be used to
    specify alternate compression methods for the archive used by
    the 'autopoint' program. These options, together with
  - -with-git, allow to trade dependencies against installed
    package size. --with-xz has the highest compression rate,
    followed by --with-git, followed by --with-bzip2.
  + Autoconf macros:
  * The autoconf macros installed by 'gettextize' now work with
    the forthcoming Automake 1.14 and require Autoconf version
    2.60 or newer.
  + Portability:
  * Building on MacOS X 10.7, Cygwin 1.7.10, and newer 64-bit
    mingw is now supported.
- Remove obsolete patches:
  + getext-stdio.in.patch
  + gettext-codecleanup.patch
* Wed Mar 27 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Sep 24 2012 pth@suse.de
- remove silent_rules from AM_INIT_AUTOMAKE to make autoreconf
  succeed on older distributions.
- Rename po-mode.diff to gettext-po-mode.diff
* Sun Jul 22 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Tue Dec 21 2010 pth@suse.de
- Update to 0.18.1. Changes since 0.17:
  Version 0.18.1 - June 2010
  * msggrep: A '$' anchor in a regular expression now also matches
    the end of the string, even if it does not end in a newline.
  * Dependencies:
    The libraries and programs are now linked with libunistring if
    this library is already installed.
  * Installation options:
    The configure option --with-cvs is deprecated. The 'autopoint'
    program will now use the 'git' program by default to compress its
    archive.  If the configure option --without-git is specified,
    'autopoint' will not rely on 'git', but will instead rely on a
    locally installed 3 MB large archive.
  Version 0.18 - May 2010
  * PO file format:
    There is a new field 'Language' in the header entry.  It denotes
    the language code (plus optional country code) for the PO file.
    This field can be used by automated tools, such as spell
    checkers. It is expected to be more reliable than looking at the
    file name or at the 'Language-Team' field in the header entry.
    msgmerge, msgcat, msgen have a new option --lang that allows to
    specify this field. Additionally, msgmerge fills in this new
    field by looking at the 'Language-Team' field (if the --lang
    option is not given).
  * xgettext and PO file format:
    For messages with plural forms, programmers can inform the
    translators about the range of possible values of the numeric
    argument, like this:
    /* xgettext: range: 0..15 */
    This information 'range: 0..15' is stored in the PO file as a
    flag attached to the message. Translators can produce better
    translations when they know that the numeric argument is small.
  * Colorized PO files:
    msgattrib, msgcomm, msgconv, msgen, msgfilter, msggrep, msginit,
    msgmerge, msgunfmt, msguniq, xgettext now have options --color
    and --style, like msgcat has since version 0.17.
  * msgmerge is up to 10 times faster when the PO and POT files are
    large. This speedup was contributed by Ralf Wildenhues.
  * msgcmp has a new option -N/--no-fuzzy-matching, like msgmerge has
    since version 0.12.
  * msgfilter now sets environment variables during the invocation of
    the filter, indicating the msgid and location of the messge being
    processed.
  * xgettext now can extract plural forms from Qt 4 programs. The
    recommended xgettext command-line options for this case are:
  - -qt --keyword=tr:1,1t --keyword=tr:1,2c,2t --keyword=tr:1,1,2c,3t
  * xgettext --language=GCC-source now recognizes also the format
    strings used in the Fortran front-end of the GCC compiler, and
    marks them as 'gfc-internal-format'.
  * autopoint can now be used to update several PO directories all
    together.
  * PO mode changes:
  - PO files with plural entries are now correctly handled.
  - Editing a message with previous msgid (in comments) removes these
    comments.  Contributed by Noritada Kobayashi.
  * The po/Makevars file has a new field MSGMERGE_OPTIONS, that can
    be used to adjust msgmerge's operation.
  * The use of the macro AM_GNU_GETTEXT without 'external' argument
    and the --intl option of the gettextize program are deprecated
    and will be removed in the next release. Instead of including
    the intl sources in your package, we suggest making the libintl
    library an (optional) prerequisite of your package.
  * Updated the meaning of 'gcc-internal-format' to match GCC 4.3.
  * Installation options:
    The configure options --without-cvs and --with-git can be used to
    specify whether 'autopoint' will use the 'cvs' program, or the
    'git' program, or none at all. These options allow to trade
    dependencies against installed package size: If --without-cvs is
    specified and --with-git is not specified, 'autopoint' will not
    rely on 'cvs' or 'git', but will instead rely on a locally
    installed a 3 MB large archive.
  * Portability: The msgfilter program now also works on native Woe32
  - platforms. Compiled C# message catalogs now also work with
  - 'mono' versions from 2009
    or newer.
* Fri Mar  5 2010 puzel@novell.com
- remove gettext-tools/gnulib-m4/openmp.m4: fix build with new
  autoconf
* Mon Jul 27 2009 rguenther@suse.de
- Remove rather than %%exclude not packaged files.
* Tue Oct 14 2008 kukuk@suse.de
- Never install files in %%check section
- Disable autoconf/libtool tests
* Mon Oct 13 2008 kukuk@suse.de
- Fix autoreconf call
* Sun May 18 2008 pth@suse.de
- Fix segmentation fault in msgmerge (bnc#391372).
* Tue Dec  4 2007 pth@suse.de
- Add patch from upstreams to add the missing mode for the open call.
* Fri Nov 23 2007 pth@suse.de
- Remove the patch for disabling a test.
* Fri Nov 16 2007 pth@suse.de
- Don't run the testsuite.
* Thu Nov 15 2007 pth@suse.de
- Rename packages: gettext -> gettext-runtime and
    gettext-devel -> gettext->tools
  Packaging closely follows uptream recommendation with a few
  exceptions.
- Initialize variable to shut up gcc.
- Disable msgmerge-compendium-5 for now.
- Reorder installation flow because libgettextlib is needed for the
  gettext-tools stuf.
- Update to 0.17:
  * License:
  The gettext related programs and tools are now licensed under the GPL
  version 3, instead of the GPL version 2.
  * PO file format:
  The Project-Id-Version field in the header entry may now already be filled
  in the POT file. In this case, the translators don't need to fill it in.
  xgettext has new options --package-name and --package-version that allow
  to specify the package name and version from a Makefile.
  * Colorized PO files:
  The msgcat program has new options --color and --style that produce a
  colorized PO file output, where keywords, strings, comments, or format
  directives can be highlighted.  See the documentation section
  "Highlighting parts of PO files" for more info.
  * gettextize now has a --po-dir option that allows several PO directories to
  be updated all together.
  * Programming languages support:
  - Contexts (msgctxt) are now also supported for Java and C#.
  - C# with Qt: The support for Qt format strings has been updated for Qt 4.
  - C++ with KDE:
    xgettext has a new option --kde that triggers the recognition and marking
    of KDE 4 format strings.
  * Autoconf macros:
  - A new macro AM_XGETTEXT_OPTION can be used as an alternative to modifying
    po/Makevars.
  * libgettextpo library:
  - New functions are available for querying the list of supported format
    types.
  - The functions po_message_comments and po_message_extracted_comments
    return a multiline string where each line no longer starts with a
    redundant space. The leading space in every comment line is now stripped
    while reading the PO file.
  - Conversely, when you pass a multiline string to the function
    po_message_set_comments or po_message_set_extracted_comments, you normally
    don't pass a space at the beginning of each line, because such spaces are
    no longer trimmed during output.
  * Documentation:
  - The "Users" chapter has been completely rewritten.
  - New section "Highlighting parts of PO files".
  - A complete example showing the use of GNU gettext in Java with the Qt/Jambi
  GUI toolkit has been added.
- Add tcl and perl-libintl-perl to BuildRequires (testsuite needs
  them).
- Remove call to gl_AC_TYPE_LONG_LONG from libasprintf's
  configure.ac
* Wed Oct 31 2007 mrueckert@suse.de
- renamed rpmlintrc to gettext-rpmlintrc and added it to the spec
  as source 1
* Mon Sep  3 2007 pth@suse.de
- Incorporate upstream patch that correctly fixes the expat
  dynloading code (http://savannah.gnu.org/bugs/?19585).
* Fri Aug 10 2007 bk@suse.de
- Update to gettext 0.16.1, required by GnuPG 2.0.5
* Thu Aug  9 2007 bk@suse.de
- re-enable make check to identify possible toolchain bugs
- move java documentation from gettext to this package
- hardlink duplicate example files in documentation
* Fri Apr 20 2007 pth@suse.de
- Make inclusion of expat.h independent of dynamic loading so
  that XML_MAJOR_VERSION is actually defined (#264110).
* Fri Mar 30 2007 pth@suse.de
- Fix use of uninitialized variables.
- Set CXXFLAGS to get C++ code compiled with RPM_BUILD_OPTS
- Sync .spec files
* Tue Mar 20 2007 rguenther@suse.de
- Remove unused expat BuildRequires.
* Wed Jan 31 2007 pth@suse.de
- Reference 0.16 .spec file
- fix spec file
* Tue Jan 16 2007 pth@suse.de
- Update to gettext 0.16
* Mon Sep 18 2006 rguenther@suse.de
- New package to host gettext java tools GetURL and DumpResource.
